/*
 * @(#)SingletonQueryStore.java				Jun 18, 2012 8:32:07 AM
 *
 * Copyright 2012 Radeon Systems
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.radeonsys.data.querystore.support;

import com.google.common.base.Preconditions;
import com.google.common.base.Strings;
import com.radeonsys.data.querystore.QueryNotFoundException;
import com.radeonsys.data.querystore.QueryStore;

/**
 * An implementation of a {@link QueryStore} which holds a single query.
 * 
 * <p>This implementation was created for tests and may not have useful 
 * applications beyond testing.</p>
 * 
 * @author oddjobsman
 * @since 1.0
 */
final class SingletonQueryStore implements QueryStore {

	/**
	 * Stores the name of the query
	 */
	private final String queryName;
	
	/**
	 * Stores the query string
	 */
	private final String queryString;

	/**
	 * Creates a new instance of {@code SingletonQueryStore} with the
	 * specified query
	 * 
	 * @param queryName		name of the query
	 * @param queryString	the query string
	 * 
	 * @throws IllegalArgumentException
	 * 			if the query name or string specified is {@code null} or empty
	 */
	public SingletonQueryStore(String queryName, String queryString) {
		Preconditions.checkArgument(!Strings.isNullOrEmpty(queryName), "A valid query name must be specified");
		Preconditions.checkArgument(!Strings.isNullOrEmpty(queryString), "A valid query string must be specified");
		
		this.queryName = queryName;
		this.queryString = queryString;
	}

	/* (non-Javadoc)
	 * @see com.radeonsys.data.querystore.QueryStore#getQuery(java.lang.String)
	 */
	@Override
	public String getQuery(String nameOfQuery) {
		if (!containsQuery(nameOfQuery))
			throw new QueryNotFoundException(nameOfQuery);
		return queryString;
	}

	/* (non-Javadoc)
	 * @see com.radeonsys.data.querystore.QueryStore#containsQuery(java.lang.String)
	 */
	@Override
	public boolean containsQuery(String queryName) {
		Preconditions.checkArgument(!Strings.isNullOrEmpty(queryName), "A valid query name must be specified");
		return this.queryName.equals(queryName);
	}

}
