/*
 * @(#)CompositeQueryStoreTest.java				Jun 18, 2012 8:04:06 AM
 *
 * Copyright 2012 Radeon Systems
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.radeonsys.data.querystore.support;

import static org.junit.Assert.assertEquals;

import java.util.Properties;

import org.easymock.EasyMock;
import org.easymock.EasyMockSupport;
import org.junit.After;
import org.junit.Test;

import com.radeonsys.data.querystore.QueryNotFoundException;
import com.radeonsys.data.querystore.QueryStore;
import com.radeonsys.data.querystore.support.properties.PropertiesQueryStore;

/**
 * Defines unit tests for {@link CompositeQueryStore}
 * 
 * @author oddjobsman
 */
public class CompositeQueryStoreTest extends EasyMockSupport {

	@Test
	public void addsQueryStoreAndLooksUpQueryStoreToGetQuery() {
		final String expectedQueryName = "TEST_QUERY";
		final String expectedQuery = "SELECT * FROM dummy";

		Properties props = new Properties();
		props.setProperty(expectedQueryName, expectedQuery);
		
		CompositeQueryStore store = new CompositeQueryStore();
		store.addQueryStore(new PropertiesQueryStore(props));
		
		assertEquals(expectedQuery, store.getQuery(expectedQueryName));
	}

	@Test
	public void looksupAllAddedQueryStoresToGetQuery() {
		final String expectedQueryName = "TEST_QUERY";
		final String expectedQuery = "SELECT * FROM dummy";
		
		QueryStore queryStoreA = createStrictMock(QueryStore.class);
		EasyMock.expect(queryStoreA.containsQuery(expectedQueryName)).andReturn(false);

		QueryStore queryStoreB = createStrictMock(QueryStore.class);
		EasyMock.expect(queryStoreB.containsQuery(expectedQueryName)).andReturn(true);
		EasyMock.expect(queryStoreB.getQuery(expectedQueryName)).andReturn(expectedQuery);
		
		replayAll();

		CompositeQueryStore store = new CompositeQueryStore();
		store.addQueryStore(queryStoreA);
		store.addQueryStore(queryStoreB);
		
		assertEquals(expectedQuery, store.getQuery(expectedQueryName));
	}

	@Test(expected=QueryNotFoundException.class)
	public void throwsQueryNotFoundExceptionIfQueryNotDefinedInAnyQueryStores() {
		final String expectedQueryName = "TEST_QUERY";
		
		QueryStore queryStoreA = createStrictMock(QueryStore.class);
		EasyMock.expect(queryStoreA.containsQuery(expectedQueryName)).andReturn(false);
		
		QueryStore queryStoreB = createStrictMock(QueryStore.class);
		EasyMock.expect(queryStoreB.containsQuery(expectedQueryName)).andReturn(false);
		
		replayAll();
		
		CompositeQueryStore store = new CompositeQueryStore();
		store.addQueryStore(queryStoreA);
		store.addQueryStore(queryStoreB);
		
		store.getQuery(expectedQueryName);
	}
	
	@After
	public void tearDown() {
		verifyAll();
		resetAll();
	}
}
