/*
 * @(#)SingletonQueryStoreTest.java				Jun 18, 2012 8:33:07 AM
 *
 * Copyright 2012 Radeon Systems
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.radeonsys.data.querystore.support;

import static org.junit.Assert.*;

import org.junit.Test;

import com.radeonsys.data.querystore.QueryNotFoundException;
import com.radeonsys.data.querystore.QueryStore;

/**
 * Defines unit tests for {@link SingletonQueryStore}
 * 
 * @see SingletonQueryStore
 * 
 * @author oddjobsman
 */
public class SingletonQueryStoreTest {

	@Test
	public void acceptsQueryNameAndStringAtCreation() {
		String expectedQueryName = "TEST_QUERY";
		String expectedQueryString = "SELECT * FROM dummy";
		
		QueryStore store = new SingletonQueryStore(expectedQueryName, expectedQueryString);
		assertEquals(expectedQueryString, store.getQuery(expectedQueryName));
	}

	@Test
	public void returnsWhetherOrNotQueryContainedInQueryStore() {
		String expectedQueryName = "TEST_QUERY";
		String expectedQueryString = "SELECT * FROM dummy";
		
		QueryStore store = new SingletonQueryStore(expectedQueryName, expectedQueryString);
		
		assertTrue(store.containsQuery(expectedQueryName));
		
		final String erroneousQueryName = "DUMMY_QUERY";
		assertFalse(store.containsQuery(erroneousQueryName));
	}
	
	@Test(expected=QueryNotFoundException.class)
	public void throwsQueryNotFoundExceptionIfGettingUnknownQueryAttempted() {
		String expectedQueryName = "TEST_QUERY";
		String expectedQueryString = "SELECT * FROM dummy";
		
		QueryStore store = new SingletonQueryStore(expectedQueryName, expectedQueryString);
		
		final String erroneousQueryName = "DUMMY_QUERY";
		store.getQuery(erroneousQueryName);
	}
}
