/*
 * @(#)PropertiesQueryStore.java				Jun 6, 2012 11:23:35 PM
 *
 * Copyright 2012 Radeon Systems
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.radeonsys.data.querystore.support.properties;

import static org.junit.Assert.*;

import java.util.Arrays;
import java.util.Properties;

import org.junit.Test;

import com.radeonsys.data.querystore.QueryStore;
import com.radeonsys.data.querystore.QueryStoreException;
import com.radeonsys.data.querystore.support.loader.classpath.ClasspathResourceLoader;
import com.radeonsys.data.querystore.support.properties.PropertiesQueryStore;

/**
 * Defines unit tests for {@link PropertiesQueryStore}
 * 
 * @see PropertiesQueryStore
 * 
 * @author oddjobsman
 */
public class PropertiesQueryStoreTest {
	
	@Test
	public void getsQueryFromProperties() {
		String queryName = "TEST_QUERY";
		String queryString = "SELECT * FROM dummy";

		Properties props = new Properties();
		props.setProperty(queryName, queryString);
		
		QueryStore store = new PropertiesQueryStore(props);
		assertEquals(queryString, store.getQuery(queryName));
	}

	@Test(expected=IllegalStateException.class)
	public void throwsIllegalStateExceptionIfInitializedWithPreBuiltProperties() {
		new PropertiesQueryStore(new Properties()).initialize();
	}

	@Test
	public void mustInitializeBeforeGettingQueriesFromResource() {
		String queryName = "TEST_QUERY";
		
		PropertiesQueryStore store = new PropertiesQueryStore(Arrays.asList(
			"com/radeonsys/data/querystore/support/properties/test-query-one.xml"
		), new ClasspathResourceLoader());
		
		store.initialize();
		
		store.getQuery(queryName);
	}
	
	@Test(expected=QueryStoreException.class)
	public void throwsQueryNotFoundExceptionIfInitializeNotCalledBeforeGettingQueriesFromResource() {
		String queryName = "TEST_QUERY";
		
		PropertiesQueryStore store = new PropertiesQueryStore(Arrays.asList(
				"com/radeonsys/data/querystore/support/properties/test-query-one.xml"
			), new ClasspathResourceLoader());
		
		store.getQuery(queryName);
	}

	@Test(expected=IllegalStateException.class)
	public void throwsIllegalStateExceptionIfInitializedAttemptedTwice() {
		PropertiesQueryStore store = new PropertiesQueryStore(Arrays.asList(
				"com/radeonsys/data/querystore/support/properties/test-query-one.xml"
			), new ClasspathResourceLoader());
		
		store.initialize();
		store.initialize();
	}
	
	@Test
	public void getsQueryFromResource() {
		String queryName = "TEST_QUERY";
		String queryString = "SELECT * FROM test\n\t\t\t\tWHERE id = 3;";
		
		PropertiesQueryStore store = new PropertiesQueryStore(Arrays.asList(
			"com/radeonsys/data/querystore/support/properties/test-query-one.xml"
		), new ClasspathResourceLoader());
		
		store.initialize();
		
		String queryFileString = store.getQuery(queryName);
		
		assertEquals(queryString, queryFileString);
	}

}
